import { ActionSheetOptions } from '@expo/react-native-action-sheet';
import PropTypes from 'prop-types';
import React from 'react';
import { Animated, FlatList, StyleProp, TextInput, TextStyle, ViewStyle } from 'react-native';
import { LightboxProps } from 'react-native-lightbox-v2';
import { Actions, ActionsProps } from './Actions';
import { Avatar, AvatarProps } from './Avatar';
import Bubble from './Bubble';
import { Composer, ComposerProps } from './Composer';
import { Day, DayProps } from './Day';
import GiftedAvatar from './GiftedAvatar';
import { InputToolbar, InputToolbarProps } from './InputToolbar';
import { LoadEarlier, LoadEarlierProps } from './LoadEarlier';
import Message from './Message';
import MessageContainer from './MessageContainer';
import { MessageImage, MessageImageProps } from './MessageImage';
import { MessageText, MessageTextProps } from './MessageText';
import { IMessage, LeftRightStyle, MessageAudioProps, MessageVideoProps, Reply, User } from './Models';
import { QuickRepliesProps } from './QuickReplies';
import { Send, SendProps } from './Send';
import { SystemMessage, SystemMessageProps } from './SystemMessage';
import { Time, TimeProps } from './Time';
import * as utils from './utils';
export interface GiftedChatProps<TMessage extends IMessage = IMessage> {
    messageContainerRef?: React.RefObject<FlatList<IMessage>>;
    textInputRef?: React.RefObject<TextInput>;
    messages?: TMessage[];
    isTyping?: boolean;
    messagesContainerStyle?: StyleProp<ViewStyle>;
    text?: string;
    alignTop?: boolean;
    scrollToBottom?: boolean;
    scrollToBottomStyle?: StyleProp<ViewStyle>;
    initialText?: string;
    placeholder?: string;
    disableComposer?: boolean;
    user?: User;
    locale?: string;
    timeFormat?: string;
    dateFormat?: string;
    loadEarlier?: boolean;
    isLoadingEarlier?: boolean;
    showUserAvatar?: boolean;
    showAvatarForEveryMessage?: boolean;
    isKeyboardInternallyHandled?: boolean;
    renderAvatarOnTop?: boolean;
    inverted?: boolean;
    imageProps?: Message<TMessage>['props'];
    lightboxProps?: LightboxProps;
    bottomOffset?: number;
    minInputToolbarHeight?: number;
    listViewProps?: any;
    textInputProps?: any;
    keyboardShouldPersistTaps?: any;
    maxInputLength?: number;
    forceGetKeyboardHeight?: boolean;
    alwaysShowSend?: boolean;
    imageStyle?: StyleProp<ViewStyle>;
    extraData?: any;
    minComposerHeight?: number;
    maxComposerHeight?: number;
    options?: {
        [key: string]: any;
    };
    optionTintColor?: string;
    quickReplyStyle?: StyleProp<ViewStyle>;
    quickReplyTextStyle?: StyleProp<TextStyle>;
    isCustomViewBottom?: boolean;
    infiniteScroll?: boolean;
    timeTextStyle?: LeftRightStyle<TextStyle>;
    actionSheet?(): {
        showActionSheetWithOptions: (options: ActionSheetOptions, callback: (i: number) => void) => void;
    };
    onPressAvatar?(user: User): void;
    onLongPressAvatar?(user: User): void;
    messageIdGenerator?(message?: TMessage): string;
    onSend?(messages: TMessage[]): void;
    onLoadEarlier?(): void;
    renderLoading?(): React.ReactNode;
    renderLoadEarlier?(props: LoadEarlierProps): React.ReactNode;
    renderAvatar?: null | ((props: AvatarProps<TMessage>) => React.ReactNode);
    renderBubble?(props: Bubble<TMessage>['props']): React.ReactNode;
    renderSystemMessage?(props: SystemMessageProps<TMessage>): React.ReactNode;
    onPress?(context: any, message: TMessage): void;
    onLongPress?(context: any, message: TMessage): void;
    renderUsername?(user: User): React.ReactNode;
    renderMessage?(message: Message<TMessage>['props']): React.ReactNode;
    renderMessageText?(messageText: MessageTextProps<TMessage>): React.ReactNode;
    renderMessageImage?(props: MessageImageProps<TMessage>): React.ReactNode;
    renderMessageVideo?(props: MessageVideoProps<TMessage>): React.ReactNode;
    renderMessageAudio?(props: MessageAudioProps<TMessage>): React.ReactNode;
    renderCustomView?(props: Bubble<TMessage>['props']): React.ReactNode;
    renderDay?(props: DayProps<TMessage>): React.ReactNode;
    renderTime?(props: TimeProps<TMessage>): React.ReactNode;
    renderFooter?(): React.ReactNode;
    renderChatEmpty?(): React.ReactNode;
    renderChatFooter?(): React.ReactNode;
    renderInputToolbar?(props: InputToolbarProps<TMessage>): React.ReactNode;
    renderComposer?(props: ComposerProps): React.ReactNode;
    renderActions?(props: ActionsProps): React.ReactNode;
    renderSend?(props: SendProps<TMessage>): React.ReactNode;
    renderAccessory?(props: InputToolbarProps<TMessage>): React.ReactNode;
    onPressActionButton?(): void;
    onInputTextChanged?(text: string): void;
    parsePatterns?(linkStyle: TextStyle): any;
    onQuickReply?(replies: Reply[]): void;
    renderQuickReplies?(quickReplies: QuickRepliesProps<TMessage>): React.ReactNode;
    renderQuickReplySend?(): React.ReactNode;
    scrollToBottomComponent?(): React.ReactNode;
    shouldUpdateMessage?(props: Message<TMessage>['props'], nextProps: Message<TMessage>['props']): boolean;
}
export interface GiftedChatState<TMessage extends IMessage = IMessage> {
    isInitialized: boolean;
    composerHeight?: number;
    messagesContainerHeight?: number | Animated.Value;
    typingDisabled: boolean;
    text?: string;
    messages?: TMessage[];
}
declare function GiftedChat<TMessage extends IMessage = IMessage>(props: GiftedChatProps): JSX.Element;
declare namespace GiftedChat {
    var propTypes: {
        messages: PropTypes.Requireable<(object | null | undefined)[]>;
        messagesContainerStyle: PropTypes.Requireable<number | boolean | object>;
        text: PropTypes.Requireable<string>;
        initialText: PropTypes.Requireable<string>;
        placeholder: PropTypes.Requireable<string>;
        disableComposer: PropTypes.Requireable<boolean>;
        messageIdGenerator: PropTypes.Requireable<(...args: any[]) => any>;
        user: PropTypes.Requireable<object>;
        onSend: PropTypes.Requireable<(...args: any[]) => any>;
        locale: PropTypes.Requireable<string>;
        timeFormat: PropTypes.Requireable<string>;
        dateFormat: PropTypes.Requireable<string>;
        isKeyboardInternallyHandled: PropTypes.Requireable<boolean>;
        loadEarlier: PropTypes.Requireable<boolean>;
        onLoadEarlier: PropTypes.Requireable<(...args: any[]) => any>;
        isLoadingEarlier: PropTypes.Requireable<boolean>;
        renderLoading: PropTypes.Requireable<(...args: any[]) => any>;
        renderLoadEarlier: PropTypes.Requireable<(...args: any[]) => any>;
        renderAvatar: PropTypes.Requireable<(...args: any[]) => any>;
        showUserAvatar: PropTypes.Requireable<boolean>;
        actionSheet: PropTypes.Requireable<(...args: any[]) => any>;
        onPressAvatar: PropTypes.Requireable<(...args: any[]) => any>;
        onLongPressAvatar: PropTypes.Requireable<(...args: any[]) => any>;
        renderUsernameOnMessage: PropTypes.Requireable<boolean>;
        renderAvatarOnTop: PropTypes.Requireable<boolean>;
        isCustomViewBottom: PropTypes.Requireable<boolean>;
        renderBubble: PropTypes.Requireable<(...args: any[]) => any>;
        renderSystemMessage: PropTypes.Requireable<(...args: any[]) => any>;
        onLongPress: PropTypes.Requireable<(...args: any[]) => any>;
        renderMessage: PropTypes.Requireable<(...args: any[]) => any>;
        renderMessageText: PropTypes.Requireable<(...args: any[]) => any>;
        renderMessageImage: PropTypes.Requireable<(...args: any[]) => any>;
        imageProps: PropTypes.Requireable<object>;
        videoProps: PropTypes.Requireable<object>;
        audioProps: PropTypes.Requireable<object>;
        lightboxProps: PropTypes.Requireable<object>;
        renderCustomView: PropTypes.Requireable<(...args: any[]) => any>;
        renderDay: PropTypes.Requireable<(...args: any[]) => any>;
        renderTime: PropTypes.Requireable<(...args: any[]) => any>;
        renderFooter: PropTypes.Requireable<(...args: any[]) => any>;
        renderChatEmpty: PropTypes.Requireable<(...args: any[]) => any>;
        renderChatFooter: PropTypes.Requireable<(...args: any[]) => any>;
        renderInputToolbar: PropTypes.Requireable<(...args: any[]) => any>;
        renderComposer: PropTypes.Requireable<(...args: any[]) => any>;
        renderActions: PropTypes.Requireable<(...args: any[]) => any>;
        renderSend: PropTypes.Requireable<(...args: any[]) => any>;
        renderAccessory: PropTypes.Requireable<(...args: any[]) => any>;
        onPressActionButton: PropTypes.Requireable<(...args: any[]) => any>;
        bottomOffset: PropTypes.Requireable<number>;
        minInputToolbarHeight: PropTypes.Requireable<number>;
        listViewProps: PropTypes.Requireable<object>;
        keyboardShouldPersistTaps: PropTypes.Requireable<string>;
        onInputTextChanged: PropTypes.Requireable<(...args: any[]) => any>;
        maxInputLength: PropTypes.Requireable<number>;
        forceGetKeyboardHeight: PropTypes.Requireable<boolean>;
        inverted: PropTypes.Requireable<boolean>;
        textInputProps: PropTypes.Requireable<object>;
        extraData: PropTypes.Requireable<object>;
        minComposerHeight: PropTypes.Requireable<number>;
        maxComposerHeight: PropTypes.Requireable<number>;
        alignTop: PropTypes.Requireable<boolean>;
    };
    var append: <TMessage extends IMessage>(currentMessages: TMessage[] | undefined, messages: TMessage[], inverted?: boolean) => TMessage[];
    var prepend: <TMessage extends IMessage>(currentMessages: TMessage[] | undefined, messages: TMessage[], inverted?: boolean) => TMessage[];
}
export * from './Models';
export { GiftedChat, Actions, Avatar, Bubble, SystemMessage, MessageImage, MessageText, Composer, Day, InputToolbar, LoadEarlier, Message, MessageContainer, Send, Time, GiftedAvatar, utils, };
